===========================
Configuration file examples
===========================

.. _configuration-examples-master:

.. contents::
    :local:
    :depth: 1

Example master configuration file
=================================

.. literalinclude:: ../../../conf/master
    :language: yaml

.. _configuration-examples-minion:

Example minion configuration file
=================================

.. literalinclude:: ../../../conf/minion
    :language: yaml